@@ -1,5 +1,7 @@
 from dnastack.client import *
 
+from dnastack.cli.utils import get_config
+
 
 @click.group()
 @click.pass_context
@@ -15,14 +17,16 @@ def list_tables(ctx, collection_name):
         click.echo(
             json.dumps(
                 collections_client.list_tables(
-                    ctx.obj["collections-url"], collection_name
+                    collections_url=get_config(ctx, "collections.url"),
+                    collection_name=collection_name,
                 ),
                 indent=4,
             )
         )
     except:
         click.secho(
-            f"Error occurred while listing tables from collection [{collection_name}] at collections_table_url {[ctx.obj['collections-url']]}",
+            f"Error occurred while listing tables from collection [{collection_name}] at collections url "
+            f"[{get_config(ctx, 'collections.url')}]",
             fg="red",
         )
         sys.exit(1)
