@@ -1,4 +1,4 @@
-from dnastack.cli.utils import assert_config, get_config
+from dnastack.cli.utils import get_config
 from dnastack.client import *
 from dnastack.client.files_client import download_files
 
