@@ -16,7 +16,7 @@ class TestCliCollectionsCommand(unittest.TestCase):
             [
                 "config",
                 "set",
-                "collections-url",
+                "collections.url",
                 self.collections_url,
             ],
         )
