@@ -11,23 +11,26 @@ class TestCliDataConnectTablesCommand(unittest.TestCase):
     def setUp(self):
         self.runner = CliRunner()
         self.data_connect_url = TEST_DATA_CONNECT_URI
-        self.runner.invoke(
-            dnastack_cli.dnastack,
-            [
-                "config",
-                "set",
-                "data-connect-url",
-                self.data_connect_url,
-            ],
-        )
-        set_auth_params(
+        self.wallet_url = TEST_AUTH_PARAMS["publisher"]["url"]
+
+        clear_config()
+        set_cli_config(self.runner, "data_connect.url", self.data_connect_url)
+        set_auth_params_for_service(
             self.runner,
-            TEST_AUTH_PARAMS["publisher"],
+            service="data-connect",
+            auth_params=TEST_AUTH_PARAMS["publisher"],
         )
         set_cli_config(
-            self.runner, "oauth_token", ["scope", TEST_AUTH_SCOPES["publisher"]]
+            self.runner,
+            f"oauth|{self.wallet_url}|scope",
+            TEST_AUTH_SCOPES["publisher"],
+            delimiter="|",
+        )
+        login_with_refresh_token_for_service(
+            self.runner,
+            service="data-connect",
+            refresh_token=TEST_WALLET_REFRESH_TOKEN["publisher"],
         )
-        login_with_refresh_token(self.runner, TEST_WALLET_REFRESH_TOKEN["publisher"])
 
     def test_tables_list(self):
         result = self.runner.invoke(
