@@ -3,6 +3,8 @@ from click.testing import CliRunner
 import pathlib
 from dnastack import __main__ as dnastack_cli
 import glob
+
+from .utils import set_cli_config
 from .. import *
 
 
@@ -10,15 +12,8 @@ class TestCliFilesCommand(unittest.TestCase):
     def setUp(self):
         self.runner = CliRunner()
         self.data_connect_url = TEST_DATA_CONNECT_URI
-        self.runner.invoke(
-            dnastack_cli.dnastack,
-            [
-                "config",
-                "set",
-                "data-connect-url",
-                self.data_connect_url,
-            ],
-        )
+
+        set_cli_config(self.runner, "data_connect.url", self.data_connect_url)
 
     def test_drs_download(self):
         result = self.runner.invoke(
